# Klasa UsmjereniGraf – pohranjena kao modul 'klasaUsmjereniGraf.py'
from turtle import *                                                    
from math import *                                                      
from matrica import *                                                   

class UsmjereniGraf:
    def __init__(self, n, grane, ime_grafa = ''):                       
        self.n = n
        self.ime_grafa = ime_grafa
        self.grane = grane
        self.mat = Matrica(self.n)
        for i in grane:
            self.mat[i] = 1                                             
        return

    @property
    def mat_susjedstva(self):                                           
        return self.mat

    @property                                                           
    def nep_pret(self):
        n_p = []
        for j in range(self.n):
            p_j = []
            for i in range(self.n):
                if self.mat[i, j] == 1:
                    p_j.append(i)
            n_p.append(p_j)
        return n_p

    @property                                                          
    def nep_sljed(self):
        n_s = []
        for i in range(self.n):
            p_i = []
            for j in range(self.n):
                if self.mat[i, j] == 1:
                    p_i.append(j)
            n_s.append(p_i)
        return n_s

    def crtati(self):
        naziv = 'Graf '
        if len(self.ime_grafa):
            naziv = naziv + self.ime_grafa
        title(naziv)                                                  
        kut_n = 360 / self.n                                            
        poz_čvora = []
        pu();setpos(0, 150); seth(180)                                  
        dot(10,'black')
        poz_čvora.append(pos())                                         
        kut_p = 90
        for i in range(1, self.n):
            kut_p += kut_n
            circle(150, kut_n)
            poz_čvora.append(pos())
            dot(10, 'black')                                            
        setpos(0, 160); seth(180)
        kut_p = 90
        write(str(0), align = 'center', font = ('Arial', 10, 'bold'))    
        for i in range(1, self.n):
            kut_p += kut_n
            circle(170, kut_n)
            write(str(i), align = 'center', font = ('Arial', 10, 'bold'))
        # crtanje grana    
        for i in range(self.n):
            x_i, y_i = poz_čvora[i]                                     
            for j in range(self.n):
                if self.mat[i,j] == 1:
                    x_j, y_j = poz_čvora[j]                             
                    d = sqrt((x_j - x_i) ** 2 + (y_j - y_i) ** 2)       
                    kut = atan2((y_j - y_i), (x_j - x_i)) * 180 / pi    
                    pu(); setpos(poz_čvora[i])                          
                    seth(kut)                                           
                    pd(); fd(d - 5); stamp()                           
        mainloop()                                                      
        return

def main():
    ime_grafa_c = 'graf_c'
    n = 5
    grane_c = [(0, 1), (0, 4), (1, 2), (1, 3), (4, 3)]
    graf_c = UsmjereniGraf(n, grane_c, ime_grafa_c)
    print('Graf {0}'.format(graf_c.ime_grafa))
    print('Matrica susjedstva\n{0}'.format(graf_c.mat_susjedstva))        
    print('Lista prethodnika\n{0}'.format(graf_c.nep_pret))               
    print('Lista sljedbenika\n{0}'.format(graf_c.nep_sljed))              
    graf_c.crtati()                                                     
    return

if __name__ == '__main__':
    main()
